@@ -32,7 +32,10 @@ from statsmodels.tools.validation import (
     string_like,
 )
 from statsmodels.tsa.base.tsa_model import TimeSeriesModel
-from statsmodels.tsa.exponential_smoothing.ets import _initialization_heuristic
+from statsmodels.tsa.exponential_smoothing.ets import (
+    _initialization_heuristic,
+    _initialization_simple,
+)
 from statsmodels.tsa.holtwinters import (
     _exponential_smoothers as smoothers,
     _smoothers as py_smoothers,
@@ -206,21 +209,19 @@ class ExponentialSmoothing(TimeSeriesModel):
         seasonal=None,
         *,
         seasonal_periods=None,
-        initialization_method=None,  # Future: 'estimated',
+        initialization_method="estimated",
         initial_level=None,
         initial_trend=None,
         initial_seasonal=None,
-        use_boxcox=None,
+        use_boxcox=False,
         bounds=None,
         dates=None,
         freq=None,
         missing="none",
     ):
-        super(ExponentialSmoothing, self).__init__(
-            endog, None, dates, freq, missing=missing
-        )
+        super().__init__(endog, None, dates, freq, missing=missing)
         self._y = self._data = array_like(
-            endog, "endog", contiguous=True, order="C"
+            endog, "endog", ndim=1, contiguous=True, order="C"
         )
         options = ("add", "mul", "additive", "multiplicative")
         trend = string_like(trend, "trend", options=options, optional=True)
@@ -268,7 +269,7 @@ class ExponentialSmoothing(TimeSeriesModel):
         self._initialization_method = string_like(
             initialization_method,
             "initialization_method",
-            optional=True,
+            optional=False,
             options=options,
         )
         self._initial_level = float_like(
@@ -280,7 +281,7 @@ class ExponentialSmoothing(TimeSeriesModel):
         self._initial_seasonal = array_like(
             initial_seasonal, "initial_seasonal", optional=True
         )
-        estimated = self._initialization_method in (None, "estimated")
+        estimated = self._initialization_method == "estimated"
         self._estimate_level = estimated
         self._estimate_trend = estimated and self.trend
         self._estimate_seasonal = estimated and self.seasonal
@@ -324,14 +325,6 @@ class ExponentialSmoothing(TimeSeriesModel):
         return bounds
 
     def _boxcox(self):
-        if (
-            self._use_boxcox is not None
-            and self._initialization_method is None
-        ):
-            raise ValueError(
-                "initialization_method must be set when use_boxcox has"
-                "been set."
-            )
         if self._use_boxcox is None or self._use_boxcox is False:
             self._lambda = np.nan
             return self._y
@@ -416,19 +409,6 @@ class ExponentialSmoothing(TimeSeriesModel):
             self._fixed_parameters = {}
 
     def _initialize(self):
-        if self._initialization_method is None:
-            msg = "initial_{0} given but no initialization method specified."
-            if self._initial_level is not None:
-                raise ValueError(msg.format("level"))
-            if self._initial_trend is not None:
-                raise ValueError(msg.format("trend"))
-            if self._initial_seasonal is not None:
-                raise ValueError(msg.format("seasonal"))
-            warnings.warn(
-                "After 0.13 initialization must be handled at model creation",
-                FutureWarning,
-            )
-            return
         if self._initialization_method == "known":
             return self._initialize_known()
         msg = (
@@ -443,8 +423,23 @@ class ExponentialSmoothing(TimeSeriesModel):
             raise ValueError(msg.format("seasonal"))
         if self._initialization_method == "legacy-heuristic":
             return self._initialize_legacy()
-        elif self._initialization_method in ("heuristic", "estimated"):
+        elif self._initialization_method == "heuristic":
             return self._initialize_heuristic()
+        elif self._initialization_method == "estimated":
+            if self.nobs < 10 + 2 * (self.seasonal_periods // 2):
+                return self._initialize_simple()
+            else:
+                return self._initialize_heuristic()
+
+    def _initialize_simple(self):
+        trend = self.trend if self.has_trend else False
+        seasonal = self.seasonal if self.has_seasonal else False
+        lvl, trend, seas = _initialization_simple(
+            self._y, trend, seasonal, self.seasonal_periods
+        )
+        self._initial_level = lvl
+        self._initial_trend = trend
+        self._initial_seasonal = seas
 
     def _initialize_heuristic(self):
         trend = self.trend if self.has_trend else False
@@ -1089,31 +1084,16 @@ class ExponentialSmoothing(TimeSeriesModel):
             lower=False,
             optional=True,
         )
-
+        # TODO: Deprecate initial_level and related parameters from fit
         if initial_level is not None or initial_trend is not None:
-            if self._initialization_method is not None:
-                raise ValueError(
-                    "Initial values were set during model construction. These "
-                    "cannot be changed during fit."
-                )
-            warnings.warn(
-                "Setting initial values during fit is deprecated and will be "
-                "removed after 0.13. These should be set during model "
-                "initialization.",
-                FutureWarning,
+            raise ValueError(
+                "Initial values were set during model construction. These "
+                "cannot be changed during fit."
             )
         if use_boxcox is not None:
-            if self._use_boxcox is not None:
-                raise ValueError(
-                    "use_boxcox was set at model initialization and cannot "
-                    "be changed"
-                )
-
-            warnings.warn(
-                "Setting use_boxcox during fit has been deprecated and will "
-                "be removed after 0.13. It must be set during model "
-                "initialization.",
-                FutureWarning,
+            raise ValueError(
+                "use_boxcox was set at model initialization and cannot "
+                "be changed"
             )
         elif self._use_boxcox is None:
             use_boxcox = False
@@ -1121,19 +1101,9 @@ class ExponentialSmoothing(TimeSeriesModel):
             use_boxcox = self._use_boxcox
 
         if use_basinhopping is not None:
-            if method is not None:
-                raise ValueError(
-                    "use_basinhopping has been deprecated and method has "
-                    "also been set. These both cannot be used.  Use only "
-                    "method instead."
-                )
-            if use_basinhopping:
-                method = "basinhopping"
-            warnings.warn(
+            raise ValueError(
                 "use_basinhopping is deprecated. Set optimization method "
-                "using 'method'. This option will be removed after 0.13 "
-                "is released.",
-                FutureWarning,
+                "using 'method'."
             )
 
         data = self._data
@@ -1566,7 +1536,7 @@ class SimpleExpSmoothing(ExponentialSmoothing):
         initialization_method=None,  # Future: 'estimated',
         initial_level=None,
     ):
-        super(SimpleExpSmoothing, self).__init__(
+        super().__init__(
             endog,
             initialization_method=initialization_method,
             initial_level=initial_level,
@@ -1638,7 +1608,7 @@ class SimpleExpSmoothing(ExponentialSmoothing):
         [1] Hyndman, Rob J., and George Athanasopoulos. Forecasting: principles
             and practice. OTexts, 2014.
         """
-        return super(SimpleExpSmoothing, self).fit(
+        return super().fit(
             smoothing_level=smoothing_level,
             optimized=optimized,
             start_params=start_params,
@@ -1721,7 +1691,7 @@ class Holt(ExponentialSmoothing):
         initial_trend=None,
     ):
         trend = "mul" if exponential else "add"
-        super(Holt, self).__init__(
+        super().__init__(
             endog,
             trend=trend,
             damped_trend=damped_trend,
@@ -1820,7 +1790,7 @@ class Holt(ExponentialSmoothing):
         [1] Hyndman, Rob J., and George Athanasopoulos. Forecasting: principles
             and practice. OTexts, 2014.
         """
-        return super(Holt, self).fit(
+        return super().fit(
             smoothing_level=smoothing_level,
             smoothing_trend=smoothing_trend,
             damping_trend=damping_trend,
